pub struct GenerateOptions {
pub specs: Vec<PathBuf>,
pub oldconfig: Option<PathBuf>,
pub output: Option<PathBuf>,
pub fmt: OutputFormat,
pub writes: Vec<String>,
pub keep_backup: bool,
}Expand description
Options for loading, merging, updating, and writing config files.
Fields
specs: Vec<PathBuf>Config specification files merged in order.
oldconfig: Option<PathBuf>Optional old config used to preserve existing values.
output: Option<PathBuf>Optional output file. If absent, generated text is returned only.
fmt: OutputFormatOutput format.
writes: Vec<String>Values to override after specs and oldconfig are loaded.
keep_backup: boolWhether to keep a .old.* backup when overwriting a changed output file.
Implementations
Sourceimpl GenerateOptions
impl GenerateOptions
Sourcepub fn new(specs: impl IntoIterator<Item = PathBuf>) -> Self
pub fn new(specs: impl IntoIterator<Item = PathBuf>) -> Self
Create TOML generation options from config specification paths.