pub struct LoadReport {
pub config: Config,
pub untouched: Vec<ConfigItem>,
pub extra: Vec<ConfigItem>,
}Expand description
Result of loading and updating config state before output generation.
Fields
config: ConfigConfig after specs, old config, and write overrides have been applied.
untouched: Vec<ConfigItem>Config items that were not present in the old config.
extra: Vec<ConfigItem>Old config items that are not present in the specification.